@@ -1,5 +1,6 @@
 from __future__ import annotations
 from abc import ABC, abstractmethod
+from typing import Optional
 from .dataTypes import Player
 from . import interactions
 
@@ -12,7 +13,7 @@ class AbstractGame(ABC):
     Remember to call super().__init__() in
     the __init__ methods of any subclass.
 
-    _hasGameStarted tracks if the game has started
+    _hasGameStarted: bool tracks if the game has started
     '''
     
     def __init__(self):
@@ -20,17 +21,26 @@ class AbstractGame(ABC):
     
     @property
     def hasGameStarted(self) -> bool:
+        '''
+        Returns if a game has started or not
+        '''
         return self._hasGameStarted
     
     def startGame(self):
+        '''
+        starts the game. This sets
+        _hasGameStarted to True. If the game
+        has already started, it throws a ValueError.
+        '''
         if self._hasGameStarted:
             raise ValueError('Game already started')
         self._hasGameStarted = True
 
     @abstractmethod
-    def joinPlayer(self, playerData: Player) -> interactions.Response:
+    def joinPlayer(self, playerData: Player, otherRequestData: Optional[str]) -> interactions.Response:
         '''
         Called when a player wants to join a Game.
+        otherRequestData is extra data that can be send by joining players to the game
         '''
         return NotImplemented
     
